package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaNewsType;
import com.huiju.estateagents.service.ITaNewsTypeService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 资讯类型表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-07-25
 */
@RestController
@RequestMapping("/api")
public class TaNewsTypeController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaNewsTypeController.class);

    @Autowired
    public ITaNewsTypeService iTaNewsTypeService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taNewsType",method= RequestMethod.GET)
    public ResponseBean taNewsTypeList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaNewsType> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaNewsType> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaNewsType> result = iTaNewsTypeService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taNewsTypeList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taNewsType 实体对象
     * @return
     */
    @RequestMapping(value="/taNewsType",method= RequestMethod.POST)
    public ResponseBean taNewsTypeAdd(@RequestBody TaNewsType taNewsType){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaNewsTypeService.save(taNewsType)){
                responseBean.addSuccess(taNewsType);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taNewsTypeAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taNewsType/{id}", method= RequestMethod.DELETE)
    public ResponseBean taNewsTypeDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaNewsTypeService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taNewsTypeDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taNewsType 实体对象
     * @return
     */
    @RequestMapping(value="/taNewsType/{id}",method= RequestMethod.PUT)
    public ResponseBean taNewsTypeUpdate(@PathVariable Integer id,
                                        @RequestBody TaNewsType taNewsType){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaNewsTypeService.updateById(taNewsType)){
                responseBean.addSuccess(taNewsType);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taNewsTypeUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taNewsType/{id}",method= RequestMethod.GET)
    public ResponseBean taNewsTypeGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaNewsTypeService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taNewsTypeDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
